@@ -3,12 +3,7 @@
 from gnuradio import gr
 from gnuradio import blocks
 import math, sys, os, time
-
-try:
-    import scipy
-except ImportError:
-    sys.stderr.write("Unable to import Scipy (www.scipy.org)\n")
-    sys.exit(1)
+import numpy
 
 try:
     import sqlite3
@@ -122,18 +117,18 @@ class helper(gr.top_block):
         self.snks = []
         self.head = blocks.head(isizeof, N)
 
-        for n in xrange(nsrcs):
+        for n in range(nsrcs):
             self.srcs.append(blocks.null_source(isizeof))
 
-        for n in xrange(nsnks):
+        for n in range(nsnks):
             self.snks.append(blocks.null_sink(osizeof))
 
         self.connect(self.srcs[0], self.head, (self.op,0))
 
-        for n in xrange(1, nsrcs):
+        for n in range(1, nsrcs):
             self.connect(self.srcs[n], (self.op,n))
 
-        for n in xrange(nsnks):
+        for n in range(nsnks):
             self.connect((self.op,n), self.snks[n])
 
 def timeit(tb, iterations):
@@ -143,10 +138,10 @@ def timeit(tb, iterations):
     '''
     r = gr.enable_realtime_scheduling()
     if r != gr.RT_OK:
-        print "Warning: failed to enable realtime scheduling"
+        print("Warning: failed to enable realtime scheduling")
 
     times = []
-    for i in xrange(iterations):
+    for i in range(iterations):
         start_time = time.time()
         tb.run()
         end_time = time.time()
@@ -163,8 +158,8 @@ def format_results(kernel, times):
     '''
     res = dict()
     res["kernel"] = kernel
-    res["avg"] = scipy.mean(times)
-    res["var"] = scipy.var(times)
+    res["avg"] = numpy.mean(times)
+    res["var"] = numpy.var(times)
     res["max"] = max(times)
     res["min"] = min(times)
     return res
