@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,9 +19,12 @@
 #include <sstream>
 #include <stdexcept>
 
+// TODO: Replace with GNU Radio logging
+#include <iostream>
+
 namespace gr {
 
-#define HIER_BLOCK2_DETAIL_DEBUG 0
+constexpr bool HIER_BLOCK2_DETAIL_DEBUG = false;
 
 hier_block2_detail::hier_block2_detail(hier_block2* owner)
     : d_owner(owner), d_parent_detail(0), d_fg(make_flowgraph())
@@ -288,7 +279,7 @@ void hier_block2_detail::disconnect(basic_block_sptr block)
         }
     }
 
-    if (edges.size() == 0) {
+    if (edges.empty()) {
         std::stringstream msg;
         msg << "cannot disconnect block " << block << ", not found";
         throw std::invalid_argument(msg.str());
@@ -560,7 +551,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
     edge_vector_t edges = d_fg->edges();
     msg_edge_vector_t msg_edges = d_fg->msg_edges();
     edge_viter_t p;
-    msg_edge_viter_t q, u;
+    msg_edge_viter_t q;
 
     // Only run setup_rpc if ControlPort config param is enabled.
     bool ctrlport_on = prefs::singleton()->get_bool("ControlPort", "on", false);
@@ -593,7 +584,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
         if (set_all_min_buff) {
             // sets the min buff for every block within hier_block2
             if (min_buff != 0) {
-                block_sptr bb = boost::dynamic_pointer_cast<block>(b);
+                block_sptr bb = std::dynamic_pointer_cast<block>(b);
                 if (bb != 0) {
                     if (bb->min_output_buffer(0) != min_buff) {
                         if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -602,7 +593,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
                         bb->set_min_output_buffer(min_buff);
                     }
                 } else {
-                    hier_block2_sptr hh = boost::dynamic_pointer_cast<hier_block2>(b);
+                    hier_block2_sptr hh = std::dynamic_pointer_cast<hier_block2>(b);
                     if (hh != 0) {
                         if (hh->min_output_buffer(0) != min_buff) {
                             if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -618,7 +609,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
         if (set_all_max_buff) {
             // sets the max buff for every block within hier_block2
             if (max_buff != 0) {
-                block_sptr bb = boost::dynamic_pointer_cast<block>(b);
+                block_sptr bb = std::dynamic_pointer_cast<block>(b);
                 if (bb != 0) {
                     if (bb->max_output_buffer(0) != max_buff) {
                         if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -627,7 +618,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
                         bb->set_max_output_buffer(max_buff);
                     }
                 } else {
-                    hier_block2_sptr hh = boost::dynamic_pointer_cast<hier_block2>(b);
+                    hier_block2_sptr hh = std::dynamic_pointer_cast<hier_block2>(b);
                     if (hh != 0) {
                         if (hh->max_output_buffer(0) != max_buff) {
                             if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -645,7 +636,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
         if (set_all_min_buff) {
             // sets the min buff for every block within hier_block2
             if (min_buff != 0) {
-                block_sptr bb = boost::dynamic_pointer_cast<block>(b);
+                block_sptr bb = std::dynamic_pointer_cast<block>(b);
                 if (bb != 0) {
                     if (bb->min_output_buffer(0) != min_buff) {
                         if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -654,7 +645,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
                         bb->set_min_output_buffer(min_buff);
                     }
                 } else {
-                    hier_block2_sptr hh = boost::dynamic_pointer_cast<hier_block2>(b);
+                    hier_block2_sptr hh = std::dynamic_pointer_cast<hier_block2>(b);
                     if (hh != 0) {
                         if (hh->min_output_buffer(0) != min_buff) {
                             if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -670,7 +661,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
         if (set_all_max_buff) {
             // sets the max buff for every block within hier_block2
             if (max_buff != 0) {
-                block_sptr bb = boost::dynamic_pointer_cast<block>(b);
+                block_sptr bb = std::dynamic_pointer_cast<block>(b);
                 if (bb != 0) {
                     if (bb->max_output_buffer(0) != max_buff) {
                         if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -679,7 +670,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
                         bb->set_max_output_buffer(max_buff);
                     }
                 } else {
-                    hier_block2_sptr hh = boost::dynamic_pointer_cast<hier_block2>(b);
+                    hier_block2_sptr hh = std::dynamic_pointer_cast<hier_block2>(b);
                     if (hh != 0) {
                         if (hh->max_output_buffer(0) != max_buff) {
                             if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -784,7 +775,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
     // Now add the list of connected input blocks
     std::stringstream msg;
     for (unsigned int i = 0; i < d_inputs.size(); i++) {
-        if (d_inputs[i].size() == 0) {
+        if (d_inputs[i].empty()) {
             msg << "In hierarchical block " << d_owner->name() << ", input " << i
                 << " is not connected internally";
             throw std::runtime_error(msg.str());
@@ -805,7 +796,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
         if (!set_all_min_buff) {
             min_buff = d_owner->min_output_buffer(i);
             if (min_buff != 0) {
-                block_sptr bb = boost::dynamic_pointer_cast<block>(blk);
+                block_sptr bb = std::dynamic_pointer_cast<block>(blk);
                 if (bb != 0) {
                     int bb_src_port = d_outputs[i].port();
                     if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -814,7 +805,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
                                   << std::endl;
                     bb->set_min_output_buffer(bb_src_port, min_buff);
                 } else {
-                    hier_block2_sptr hh = boost::dynamic_pointer_cast<hier_block2>(blk);
+                    hier_block2_sptr hh = std::dynamic_pointer_cast<hier_block2>(blk);
                     if (hh != 0) {
                         int hh_src_port = d_outputs[i].port();
                         if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -829,7 +820,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
         if (!set_all_max_buff) {
             max_buff = d_owner->max_output_buffer(i);
             if (max_buff != 0) {
-                block_sptr bb = boost::dynamic_pointer_cast<block>(blk);
+                block_sptr bb = std::dynamic_pointer_cast<block>(blk);
                 if (bb != 0) {
                     int bb_src_port = d_outputs[i].port();
                     if (HIER_BLOCK2_DETAIL_DEBUG)
@@ -838,7 +829,7 @@ void hier_block2_detail::flatten_aux(flat_flowgraph_sptr sfg) const
                                   << std::endl;
                     bb->set_max_output_buffer(bb_src_port, max_buff);
                 } else {
-                    hier_block2_sptr hh = boost::dynamic_pointer_cast<hier_block2>(blk);
+                    hier_block2_sptr hh = std::dynamic_pointer_cast<hier_block2>(blk);
                     if (hh != 0) {
                         int hh_src_port = d_outputs[i].port();
                         if (HIER_BLOCK2_DETAIL_DEBUG)
