@@ -1,26 +1,13 @@
 #!/usr/bin/env python
 #
-#Copyright 2004, 2007, 2010, 2012, 2013, 2020 Free Software Foundation, Inc.
+# Copyright 2004, 2007, 2010, 2012, 2013, 2020 Free Software Foundation, Inc.
 #
-#This file is part of GNU Radio
+# This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import division
 
 import math
 import pmt
@@ -36,7 +23,7 @@ class test_sig_source(gr_unittest.TestCase):
 
     def test_const_f(self):
         tb = self.tb
-        expected_result = (1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5)
+        expected_result = [1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5]
         src1 = analog.sig_source_f(1e6, analog.GR_CONST_WAVE, 0, 1.5)
         op = blocks.head(gr.sizeof_float, 10)
         dst1 = blocks.vector_sink_f()
@@ -48,7 +35,7 @@ class test_sig_source(gr_unittest.TestCase):
 
     def test_const_i(self):
         tb = self.tb
-        expected_result = (1, 1, 1, 1)
+        expected_result = [1, 1, 1, 1]
         src1 = analog.sig_source_i(1e6, analog.GR_CONST_WAVE, 0, 1)
         op = blocks.head(gr.sizeof_int, 4)
         dst1 = blocks.vector_sink_i()
@@ -60,7 +47,7 @@ class test_sig_source(gr_unittest.TestCase):
 
     def test_const_b(self):
         tb = self.tb
-        expected_result = (1, 1, 1, 1)
+        expected_result = [1, 1, 1, 1]
         src1 = analog.sig_source_b(1e6, analog.GR_CONST_WAVE, 0, 1)
         op = blocks.head(gr.sizeof_char, 4)
         dst1 = blocks.vector_sink_b()
@@ -73,7 +60,7 @@ class test_sig_source(gr_unittest.TestCase):
     def test_sine_f(self):
         tb = self.tb
         sqrt2 = math.sqrt(2) / 2
-        expected_result = (0, sqrt2, 1, sqrt2, 0, -sqrt2, -1, -sqrt2, 0)
+        expected_result = [0, sqrt2, 1, sqrt2, 0, -sqrt2, -1, -sqrt2, 0]
         src1 = analog.sig_source_f(8, analog.GR_SIN_WAVE, 1.0, 1.0)
         op = blocks.head(gr.sizeof_float, 9)
         dst1 = blocks.vector_sink_f()
@@ -86,7 +73,7 @@ class test_sig_source(gr_unittest.TestCase):
     def test_sine_b(self):
         tb = self.tb
         sqrt2 = math.sqrt(2) / 2
-        temp_result = (0, sqrt2, 1, sqrt2, 0, -sqrt2, -1, -sqrt2, 0)
+        temp_result = [0, sqrt2, 1, sqrt2, 0, -sqrt2, -1, -sqrt2, 0]
         amp = 8
         expected_result = tuple([int(z * amp) for z in temp_result])
         src1 = analog.sig_source_b(8, analog.GR_SIN_WAVE, 1.0, amp)
@@ -96,14 +83,14 @@ class test_sig_source(gr_unittest.TestCase):
         tb.connect(op, dst1)
         tb.run()
         dst_data = dst1.data()
-        #Let the python know we are dealing with signed int behind scenes
+        # Let the python know we are dealing with signed int behind scenes
         dst_data_signed = [b if b < 127 else (256 - b) * -1 for b in dst_data]
         self.assertFloatTuplesAlmostEqual(expected_result, dst_data_signed)
 
     def test_cosine_f(self):
         tb = self.tb
         sqrt2 = math.sqrt(2) / 2
-        expected_result = (1, sqrt2, 0, -sqrt2, -1, -sqrt2, 0, sqrt2, 1)
+        expected_result = [1, sqrt2, 0, -sqrt2, -1, -sqrt2, 0, sqrt2, 1]
         src1 = analog.sig_source_f(8, analog.GR_COS_WAVE, 1.0, 1.0)
         op = blocks.head(gr.sizeof_float, 9)
         dst1 = blocks.vector_sink_f()
@@ -131,8 +118,8 @@ class test_sig_source(gr_unittest.TestCase):
         self.assertFloatTuplesAlmostEqual(expected_result, dst_data, 5)
 
     def test_sqr_c(self):
-        tb = self.tb			#arg6 is a bit before -PI/2
-        expected_result = (1j, 1j, 0, 0, 1, 1, 1+0j, 1+1j, 1j)
+        tb = self.tb  # arg6 is a bit before -PI/2
+        expected_result = [1j, 1j, 0, 0, 1, 1, 1 + 0j, 1 + 1j, 1j]
         src1 = analog.sig_source_c(8, analog.GR_SQR_WAVE, 1.0, 1.0)
         op = blocks.head(gr.sizeof_gr_complex, 9)
         dst1 = blocks.vector_sink_c()
@@ -140,7 +127,7 @@ class test_sig_source(gr_unittest.TestCase):
         tb.connect(op, dst1)
         tb.run()
         dst_data = dst1.data()
-        self.assertComplexTuplesAlmostEqual(expected_result, dst_data, 5)
+        self.assertEqual(expected_result, dst_data)
 
     def test_tri_c(self):
         tb = self.tb
@@ -174,7 +161,7 @@ class test_sig_source(gr_unittest.TestCase):
 
     def test_sqr_f(self):
         tb = self.tb
-        expected_result = (0, 0, 0, 0, 1, 1, 1, 1, 0)
+        expected_result = [0, 0, 0, 0, 1, 1, 1, 1, 0]
         src1 = analog.sig_source_f(8, analog.GR_SQR_WAVE, 1.0, 1.0)
         op = blocks.head(gr.sizeof_float, 9)
         dst1 = blocks.vector_sink_f()
@@ -186,7 +173,7 @@ class test_sig_source(gr_unittest.TestCase):
 
     def test_tri_f(self):
         tb = self.tb
-        expected_result = (1, .75, .5, .25, 0, .25, .5, .75, 1)
+        expected_result = [1, .75, .5, .25, 0, .25, .5, .75, 1]
         src1 = analog.sig_source_f(8, analog.GR_TRI_WAVE, 1.0, 1.0)
         op = blocks.head(gr.sizeof_float, 9)
         dst1 = blocks.vector_sink_f()
@@ -198,7 +185,7 @@ class test_sig_source(gr_unittest.TestCase):
 
     def test_saw_f(self):
         tb = self.tb
-        expected_result = (.5, .625, .75, .875, 0, .125, .25, .375, .5)
+        expected_result = [.5, .625, .75, .875, 0, .125, .25, .375, .5]
         src1 = analog.sig_source_f(8, analog.GR_SAW_WAVE, 1.0, 1.0)
         op = blocks.head(gr.sizeof_float, 9)
         dst1 = blocks.vector_sink_f()
@@ -247,4 +234,4 @@ class test_sig_source(gr_unittest.TestCase):
 
 
 if __name__ == '__main__':
-    gr_unittest.run(test_sig_source, "test_sig_source.xml")
+    gr_unittest.run(test_sig_source)
