@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +16,6 @@
 #include <gnuradio/io_signature.h>
 #include <gnuradio/thread/thread.h>
 #include <fcntl.h>
-#include <stdio.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <cstdio>
@@ -37,9 +24,9 @@
 #ifdef _MSC_VER
 #define GR_FSEEK _fseeki64
 #define GR_FTELL _ftelli64
-#define GR_FSTAT _fstat
+#define GR_FSTAT _fstati64
 #define GR_FILENO _fileno
-#define GR_STAT _stat
+#define GR_STAT _stati64
 #define S_ISREG(m) (((m)&S_IFMT) == S_IFREG)
 #else
 #define GR_FSEEK fseeko
@@ -58,8 +45,8 @@ file_source::sptr file_source::make(size_t itemsize,
                                     uint64_t start_offset_items,
                                     uint64_t length_items)
 {
-    return gnuradio::get_initial_sptr(new file_source_impl(
-        itemsize, filename, repeat, start_offset_items, length_items));
+    return gnuradio::make_block_sptr<file_source_impl>(
+        itemsize, filename, repeat, start_offset_items, length_items);
 }
 
 file_source_impl::file_source_impl(size_t itemsize,
@@ -162,7 +149,9 @@ void file_source_impl::open(const char* filename,
 
     if (d_seekable) {
         // Check to ensure the file will be consumed according to item size
-        GR_FSEEK(d_new_fp, 0, SEEK_END);
+        if (GR_FSEEK(d_new_fp, 0, SEEK_END) == -1) {
+            throw std::runtime_error("can't fseek()");
+        }
         file_size = GR_FTELL(d_new_fp);
 
         // Make sure there will be at least one item available
@@ -198,7 +187,36 @@ void file_source_impl::open(const char* filename,
 
     // Rewind to start offset
     if (d_seekable) {
-        GR_FSEEK(d_new_fp, start_offset_items * d_itemsize, SEEK_SET);
+        auto start_offset = start_offset_items * d_itemsize;
+#ifdef _POSIX_C_SOURCE
+#if _POSIX_C_SOURCE >= 200112L
+        // If supported, tell the OS that we'll be accessing the file sequentially
+        // and that it would be a good idea to start prefetching it
+        auto fd = fileno(d_new_fp);
+        static const std::map<int, const std::string> fadv_errstrings = {
+            { EBADF, "bad file descriptor" },
+            { EINVAL, "invalid advise" },
+            { ESPIPE, "tried to act as if a pipe or similar was a file" }
+        };
+        if (file_size && file_size != INT64_MAX) {
+            if (auto ret = posix_fadvise(
+                    fd, start_offset, file_size - start_offset, POSIX_FADV_SEQUENTIAL)) {
+                GR_LOG_WARN(d_logger,
+                            "failed to advise to read sequentially, " +
+                                fadv_errstrings.at(ret));
+            }
+            if (auto ret = posix_fadvise(
+                    fd, start_offset, file_size - start_offset, POSIX_FADV_WILLNEED)) {
+                GR_LOG_WARN(d_logger,
+                            "failed to advise we'll need file contents soon, " +
+                                fadv_errstrings.at(ret));
+            }
+        }
+#endif
+#endif
+        if (GR_FSEEK(d_new_fp, start_offset, SEEK_SET) == -1) {
+            throw std::runtime_error("can't fseek()");
+        }
     }
 
     d_updated = true;
@@ -251,8 +269,9 @@ int file_source_impl::work(int noutput_items,
     gr::thread::scoped_lock lock(fp_mutex); // hold for the rest of this function
 
     // No items remaining - all done
-    if (d_items_remaining == 0)
+    if (d_items_remaining == 0) {
         return WORK_DONE;
+    }
 
     while (size) {
 
@@ -268,20 +287,30 @@ int file_source_impl::work(int noutput_items,
 
         uint64_t nitems_to_read = std::min(size, d_items_remaining);
 
-        // Since the bounds of the file are known, unexpected nitems is an error
-        if (nitems_to_read != fread(o, d_itemsize, nitems_to_read, (FILE*)d_fp))
-            throw std::runtime_error("fread error");
+        size_t nitems_read = fread(o, d_itemsize, nitems_to_read, (FILE*)d_fp);
+        if (nitems_to_read != nitems_read) {
+            // Size of non-seekable files is unknown. EOF is normal.
+            if (!d_seekable && feof((FILE*)d_fp)) {
+                size -= nitems_read;
+                d_items_remaining = 0;
+                break;
+            }
 
-        size -= nitems_to_read;
-        d_items_remaining -= nitems_to_read;
-        o += nitems_to_read * d_itemsize;
+            throw std::runtime_error("fread error");
+        }
+
+        size -= nitems_read;
+        d_items_remaining -= nitems_read;
+        o += nitems_read * d_itemsize;
 
         // Ran out of items ("EOF")
         if (d_items_remaining == 0) {
 
             // Repeat: rewind and request tag
             if (d_repeat && d_seekable) {
-                GR_FSEEK(d_fp, d_start_offset_items * d_itemsize, SEEK_SET);
+                if (GR_FSEEK(d_fp, d_start_offset_items * d_itemsize, SEEK_SET) == -1) {
+                    throw std::runtime_error("can't fseek()");
+                }
                 d_items_remaining = d_length_items;
                 if (d_add_begin_tag != pmt::PMT_NIL) {
                     d_file_begin = true;
