@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +14,6 @@
 
 #include "tag_debug_impl.h"
 #include <gnuradio/io_signature.h>
-#include <iomanip>
 #include <iostream>
 
 namespace gr {
@@ -36,8 +23,8 @@ tag_debug::sptr tag_debug::make(size_t sizeof_stream_item,
                                 const std::string& name,
                                 const std::string& key_filter)
 {
-    return gnuradio::get_initial_sptr(
-        new tag_debug_impl(sizeof_stream_item, name, key_filter));
+    return gnuradio::make_block_sptr<tag_debug_impl>(
+        sizeof_stream_item, name, key_filter);
 }
 
 tag_debug_impl::tag_debug_impl(size_t sizeof_stream_item,
@@ -47,7 +34,8 @@ tag_debug_impl::tag_debug_impl(size_t sizeof_stream_item,
                  io_signature::make(1, -1, sizeof_stream_item),
                  io_signature::make(0, 0, 0)),
       d_name(name),
-      d_display(true)
+      d_display(true),
+      d_save_all(false)
 {
     set_key_filter(key_filter);
 }
@@ -57,7 +45,12 @@ tag_debug_impl::~tag_debug_impl() {}
 std::vector<tag_t> tag_debug_impl::current_tags()
 {
     gr::thread::scoped_lock l(d_mutex);
-    return d_tags;
+
+    if (d_save_all) {
+        return d_tags;
+    } else {
+        return d_work_tags;
+    }
 }
 
 int tag_debug_impl::num_tags()
@@ -69,9 +62,20 @@ int tag_debug_impl::num_tags()
 
 void tag_debug_impl::set_display(bool d) { d_display = d; }
 
+void tag_debug_impl::set_save_all(bool s)
+{
+    gr::thread::scoped_lock l(d_mutex);
+
+    if (d_save_all && !s) {
+        d_tags.clear();
+    }
+
+    d_save_all = s;
+}
+
 void tag_debug_impl::set_key_filter(const std::string& key_filter)
 {
-    if (key_filter == "")
+    if (key_filter.empty())
         d_filter = pmt::PMT_NIL;
     else
         d_filter = pmt::intern(key_filter);
@@ -98,30 +102,33 @@ int tag_debug_impl::work(int noutput_items,
         abs_N = nitems_read(i);
         end_N = abs_N + (uint64_t)(noutput_items);
 
-        d_tags.clear();
+        d_work_tags.clear();
         if (pmt::is_null(d_filter))
-            get_tags_in_range(d_tags, i, abs_N, end_N);
+            get_tags_in_range(d_work_tags, i, abs_N, end_N);
         else
-            get_tags_in_range(d_tags, i, abs_N, end_N, d_filter);
+            get_tags_in_range(d_work_tags, i, abs_N, end_N, d_filter);
 
-        if (d_tags.size() > 0) {
+        if (!d_work_tags.empty())
             toprint = true;
-        }
 
         if (d_display) {
             sout << "Input Stream: " << std::setw(2) << std::setfill('0') << i
                  << std::setfill(' ') << std::endl;
-            for (d_tags_itr = d_tags.begin(); d_tags_itr != d_tags.end(); d_tags_itr++) {
-                sout << std::setw(10) << "Offset: " << d_tags_itr->offset << std::setw(10)
+            for (const auto& tag : d_work_tags) {
+                sout << std::setw(10) << "Offset: " << tag.offset << std::setw(10)
                      << "Source: "
-                     << (pmt::is_symbol(d_tags_itr->srcid)
-                             ? pmt::symbol_to_string(d_tags_itr->srcid)
-                             : "n/a")
-                     << std::setw(10) << "Key: " << pmt::symbol_to_string(d_tags_itr->key)
+                     << (pmt::is_symbol(tag.srcid) ? pmt::symbol_to_string(tag.srcid)
+                                                   : "n/a")
+                     << std::setw(10) << "Key: " << pmt::symbol_to_string(tag.key)
                      << std::setw(10) << "Value: ";
-                sout << d_tags_itr->value << std::endl;
+                sout << tag.value << std::endl;
             }
         }
+
+        if (d_save_all) {
+            for (const auto& tag : d_work_tags)
+                d_tags.push_back(tag);
+        }
     }
 
     if (d_display) {
