@@ -1,23 +1,12 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2013 Free Software Foundation, Inc.
+ * Copyright 2021 Marcus Müller
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,7 +34,7 @@ namespace blocks {
 tuntap_pdu::sptr tuntap_pdu::make(std::string dev, int MTU, bool istunflag)
 {
 #if (defined(linux) || defined(__linux) || defined(__linux__))
-    return gnuradio::get_initial_sptr(new tuntap_pdu_impl(dev, MTU, istunflag));
+    return gnuradio::make_block_sptr<tuntap_pdu_impl>(dev, MTU, istunflag);
 #else
     throw std::runtime_error("tuntap_pdu not implemented on this platform");
 #endif
@@ -59,9 +48,11 @@ tuntap_pdu_impl::tuntap_pdu_impl(std::string dev, int MTU, bool istunflag)
       d_istunflag(istunflag)
 {
     // make the tuntap
-    char dev_cstr[1024];
-    memset(dev_cstr, 0x00, 1024);
-    strncpy(dev_cstr, dev.c_str(), std::min(sizeof(dev_cstr), dev.size()));
+    char dev_cstr[IFNAMSIZ];
+    memset(dev_cstr, 0x00, IFNAMSIZ);
+    strncpy(dev_cstr, dev.c_str(), IFNAMSIZ);
+    dev_cstr[IFNAMSIZ - 1] = '\0';
+
 
     bool istun = d_istunflag;
     if (istun) {
@@ -75,20 +66,22 @@ tuntap_pdu_impl::tuntap_pdu_impl(std::string dev, int MTU, bool istunflag)
             "gr::tuntap_pdu::make: tun_alloc failed (are you running as root?)");
 
     int err = set_mtu(dev_cstr, MTU);
-    if (err < 0)
-        std::cerr << boost::format("gr::tuntap_pdu: failed to set MTU to %d.\n"
-                                   "You should use ifconfig to set the MTU. E.g.,\n"
-                                   "  $ sudo ifconfig %s mtu %d\n") %
-                         MTU % dev % MTU
-                  << std::endl;
+    if (err < 0) {
+        std::ostringstream msg;
+        msg << boost::format("failed to set MTU to %d. You should use ifconfig to set "
+                             "the MTU. E.g., `$ sudo ifconfig %s mtu %d`") %
+                   MTU % dev % MTU;
+        GR_LOG_ERROR(d_logger, msg.str());
+    }
 
-    std::cout << boost::format("Allocated virtual ethernet interface: %s\n"
+
+    GR_LOG_WARN(d_logger,
+                (boost::format("Allocated virtual ethernet interface: %s\n"
                                "You must now use ifconfig to set its IP address. E.g.,\n"
                                "  $ sudo ifconfig %s 192.168.200.1\n"
                                "Be sure to use a different address in the same subnet "
                                "for each machine.\n") %
-                     dev % dev
-              << std::endl;
+                 dev % dev));
 
     // set up output message port
     message_port_register_out(pdu::pdu_port_id());
@@ -96,7 +89,7 @@ tuntap_pdu_impl::tuntap_pdu_impl(std::string dev, int MTU, bool istunflag)
 
     // set up input message port
     message_port_register_in(pdu::pdu_port_id());
-    set_msg_handler(pdu::pdu_port_id(), boost::bind(&tuntap_pdu_impl::send, this, _1));
+    set_msg_handler(pdu::pdu_port_id(), [this](pmt::pmt_t msg) { this->send(msg); });
 }
 
 int tuntap_pdu_impl::tun_alloc(char* dev, int flags)
@@ -125,8 +118,20 @@ int tuntap_pdu_impl::tun_alloc(char* dev, int flags)
      * the kernel will try to allocate the "next" device of the
      * specified type
      */
-    if (*dev)
+
+#if defined(__GNUG__) && !defined(__clang__) && (__GNUC__ >= 8)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
+
+    if (*dev) {
+        // copy at most IFNAMSIZ - 1: If everything went well, the last byte is 0 anyway
         strncpy(ifr.ifr_name, dev, IFNAMSIZ - 1);
+    }
+
+#if defined(__GNUG__) && !defined(__clang__) && (__GNUC__ >= 8)
+#pragma GCC diagnostic pop
+#endif
 
     /* try to create the device */
     if ((err = ioctl(fd, TUNSETIFF, (void*)&ifr)) < 0) {
@@ -161,6 +166,7 @@ int tuntap_pdu_impl::set_mtu(const char* dev, int MTU)
     /* preparation of the struct ifr, of type "struct ifreq" */
     memset(&ifr, 0, sizeof(ifr));
     strncpy(ifr.ifr_name, dev, IFNAMSIZ);
+    ifr.ifr_name[IFNAMSIZ - 1] = '\0';
     ifr.ifr_addr.sa_family = AF_INET; /* address family */
     ifr.ifr_mtu = MTU;
 
