@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,7 +20,7 @@ namespace digital {
 
 scrambler_bb::sptr scrambler_bb::make(int mask, int seed, int len)
 {
-    return gnuradio::get_initial_sptr(new scrambler_bb_impl(mask, seed, len));
+    return gnuradio::make_block_sptr<scrambler_bb_impl>(mask, seed, len);
 }
 
 scrambler_bb_impl::scrambler_bb_impl(int mask, int seed, int len)
