@@ -4,25 +4,14 @@
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
 
 from gnuradio import gr, gr_unittest, blocks, filter, digital
 
+
 class test_simple_correlator(gr_unittest.TestCase):
 
     def setUp(self):
@@ -32,16 +21,17 @@ class test_simple_correlator(gr_unittest.TestCase):
         self.tb = None
 
     def test_00(self):
-        expected_result = (
+        expected_result = [
             0x00, 0x11, 0x22, 0x33,
             0x44, 0x55, 0x66, 0x77,
             0x88, 0x99, 0xaa, 0xbb,
-            0xcc, 0xdd, 0xee, 0xff)
+            0xcc, 0xdd, 0xee, 0xff
+        ]
 
         # Filter taps to expand the data to oversample by 8
         # Just using a RRC for some basic filter shape
         taps = filter.firdes.root_raised_cosine(8, 8, 1.0, 0.5, 21)
-        
+
         src = blocks.vector_source_b(expected_result)
         frame = digital.simple_framer(4)
         unpack = blocks.packed_to_unpacked_bb(1, gr.GR_MSB_FIRST)
@@ -58,5 +48,6 @@ class test_simple_correlator(gr_unittest.TestCase):
 
         self.assertEqual(expected_result, result_data)
 
+
 if __name__ == '__main__':
-    gr_unittest.run(test_simple_correlator, "test_simple_correlator.xml")
+    gr_unittest.run(test_simple_correlator)
