@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,7 +21,7 @@ namespace dtv {
 
 atsc_deinterleaver::sptr atsc_deinterleaver::make()
 {
-    return gnuradio::get_initial_sptr(new atsc_deinterleaver_impl());
+    return gnuradio::make_block_sptr<atsc_deinterleaver_impl>();
 }
 
 atsc_deinterleaver_impl::atsc_deinterleaver_impl()
@@ -42,25 +30,22 @@ atsc_deinterleaver_impl::atsc_deinterleaver_impl()
                      io_signature::make(1, 1, sizeof(atsc_mpeg_packet_rs_encoded))),
       alignment_fifo(156)
 {
-    m_fifo.resize(52);
+    m_fifo.reserve(s_interleavers);
 
-    for (int i = 0; i < 52; i++)
-        m_fifo[52 - 1 - i] = new interleaver_fifo<unsigned char>(i * 4);
+    for (int i = 0; i < s_interleavers; i++)
+        m_fifo.emplace_back((s_interleavers - 1 - i) * 4);
 
     sync();
 }
 
-atsc_deinterleaver_impl::~atsc_deinterleaver_impl()
-{
-    for (int i = 0; i < 52; i++)
-        delete m_fifo[i];
-}
+atsc_deinterleaver_impl::~atsc_deinterleaver_impl() {}
 
 void atsc_deinterleaver_impl::reset()
 {
     sync();
-    for (int i = 0; i < 52; i++)
-        m_fifo[i]->reset();
+
+    for (auto& i : m_fifo)
+        i.reset();
 }
 
 int atsc_deinterleaver_impl::work(int noutput_items,
@@ -79,8 +64,8 @@ int atsc_deinterleaver_impl::work(int noutput_items,
         if (in[i].pli.first_regular_seg_p())
             sync();
 
-        // remap OUTPUT pipeline info to reflect 52 data segment end-to-end delay
-        plinfo::delay(out[i].pli, in[i].pli, 52);
+        // remap OUTPUT pipeline info to reflect all data segment end-to-end delay
+        plinfo::delay(out[i].pli, in[i].pli, s_interleavers);
 
         // now do the actual deinterleaving
         for (unsigned int j = 0; j < sizeof(in[i].data); j++) {
