@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +14,7 @@
 
 #include "tagged_decoder_impl.h"
 #include <gnuradio/io_signature.h>
-#include <stdio.h>
+#include <cstdio>
 
 namespace gr {
 namespace fec {
@@ -37,8 +25,8 @@ tagged_decoder::sptr tagged_decoder::make(generic_decoder::sptr my_decoder,
                                           const std::string& lengthtagname,
                                           int mtu)
 {
-    return gnuradio::get_initial_sptr(new tagged_decoder_impl(
-        my_decoder, input_item_size, output_item_size, lengthtagname, mtu));
+    return gnuradio::make_block_sptr<tagged_decoder_impl>(
+        my_decoder, input_item_size, output_item_size, lengthtagname, mtu);
 }
 
 tagged_decoder_impl::tagged_decoder_impl(generic_decoder::sptr my_decoder,
