@@ -4,26 +4,16 @@
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
 from gnuradio import gr
 from gnuradio import blocks
 from gnuradio import filter
+from gnuradio.fft import window
 import sys, time
+import numpy
 
 try:
     from gnuradio import analog
@@ -31,13 +21,6 @@ except ImportError:
     sys.stderr.write("Error: Program requires gr-analog.\n")
     sys.exit(1)
 
-try:
-    import scipy
-    from scipy import fftpack
-except ImportError:
-    sys.stderr.write("Error: Program requires scipy (see: www.scipy.org).\n")
-    sys.exit(1)
-
 try:
     import pylab
     from pylab import mlab
@@ -56,20 +39,20 @@ class pfb_top_block(gr.top_block):
         # Create a set of taps for the PFB channelizer
         self._taps = filter.firdes.low_pass_2(1, self._fs, 500, 20,
                                               attenuation_dB=10,
-                                              window=filter.firdes.WIN_BLACKMAN_hARRIS)
+                                              window=window.WIN_BLACKMAN_hARRIS)
 
         # Calculate the number of taps per channel for our own information
-        tpc = scipy.ceil(float(len(self._taps)) /  float(self._M))
-        print "Number of taps:     ", len(self._taps)
-        print "Number of channels: ", self._M
-        print "Taps per channel:   ", tpc
+        tpc = numpy.ceil(float(len(self._taps)) / float(self._M))
+        print("Number of taps:     ", len(self._taps))
+        print("Number of channels: ", self._M)
+        print("Taps per channel:   ", tpc)
 
         repeated = True
         if(repeated):
             self.vco_input = analog.sig_source_f(self._fs, analog.GR_SIN_WAVE, 0.25, 110)
         else:
             amp = 100
-            data = scipy.arange(0, amp, amp/float(self._N))
+            data = numpy.arange(0, amp, amp / float(self._N))
             self.vco_input = blocks.vector_source_f(data, False)
 
         # Build a VCO controlled by either the sinusoid or single chirp tone
@@ -92,7 +75,7 @@ class pfb_top_block(gr.top_block):
 
         # Create a vector sink for each of M output channels of the filter and connect it
         self.snks = list()
-        for i in xrange(self._M):
+        for i in range(self._M):
             self.snks.append(blocks.vector_sink_c())
             self.connect((self.pfb, i), self.snks[i])
 
@@ -104,7 +87,7 @@ def main():
     tb.run()
 
     tend = time.time()
-    print "Run time: %f" % (tend - tstart)
+    print("Run time: %f" % (tend - tstart))
 
     if 1:
         fig_in = pylab.figure(1, figsize=(16,9), facecolor="w")
@@ -116,18 +99,18 @@ def main():
         Ne = 20000
 
         fftlen = 8192
-        winfunc = scipy.blackman
+        winfunc = numpy.blackman
         fs = tb._fs
 
         # Plot the input signal on its own figure
         d = tb.snk_i.data()[Ns:Ne]
         spin_f = fig_in.add_subplot(2, 1, 1)
 
-        X,freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen/4, Fs=fs,
+        X,freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs,
                           window = lambda d: d*winfunc(fftlen),
                           scale_by_freq=True)
-        X_in = 10.0*scipy.log10(abs(fftpack.fftshift(X)))
-        f_in = scipy.arange(-fs/2.0, fs/2.0, fs/float(X_in.size))
+        X_in = 10.0*numpy.log10(abs(numpy.fft.fftshift(X)))
+        f_in = numpy.arange(-fs / 2.0, fs / 2.0, fs / float(X_in.size))
         pin_f = spin_f.plot(f_in, X_in, "b")
         spin_f.set_xlim([min(f_in), max(f_in)+1])
         spin_f.set_ylim([-200.0, 50.0])
@@ -137,11 +120,11 @@ def main():
         spin_f.set_ylabel("Power (dBW)")
 
 
-        Ts = 1.0/fs
+        Ts = 1.0 / fs
         Tmax = len(d)*Ts
 
-        t_in = scipy.arange(0, Tmax, Ts)
-        x_in = scipy.array(d)
+        t_in = numpy.arange(0, Tmax, Ts)
+        x_in = numpy.array(d)
         spin_t = fig_in.add_subplot(2, 1, 2)
         pin_t = spin_t.plot(t_in, x_in.real, "b")
         pin_t = spin_t.plot(t_in, x_in.imag, "r")
@@ -149,27 +132,27 @@ def main():
         spin_t.set_xlabel("Time (s)")
         spin_t.set_ylabel("Amplitude")
 
-        Ncols = int(scipy.floor(scipy.sqrt(tb._M)))
-        Nrows = int(scipy.floor(tb._M / Ncols))
+        Ncols = int(numpy.floor(numpy.sqrt(tb._M)))
+        Nrows = int(numpy.floor(tb._M / Ncols))
         if(tb._M % Ncols != 0):
             Nrows += 1
 
         # Plot each of the channels outputs. Frequencies on Figure 2 and
         # time signals on Figure 3
         fs_o = tb._fs / tb._M
-        Ts_o = 1.0/fs_o
+        Ts_o = 1.0 / fs_o
         Tmax_o = len(d)*Ts_o
-        for i in xrange(len(tb.snks)):
+        for i in range(len(tb.snks)):
             # remove issues with the transients at the beginning
             # also remove some corruption at the end of the stream
             #    this is a bug, probably due to the corner cases
             d = tb.snks[i].data()[Ns:Ne]
 
             sp1_f = fig1.add_subplot(Nrows, Ncols, 1+i)
-            X,freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen/4, Fs=fs_o,
+            X,freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs_o,
                               window = lambda d: d*winfunc(fftlen),
                               scale_by_freq=True)
-            X_o = 10.0*scipy.log10(abs(X))
+            X_o = 10.0*numpy.log10(abs(X))
             f_o = freq
             p2_f = sp1_f.plot(f_o, X_o, "b")
             sp1_f.set_xlim([min(f_o), max(f_o)+1])
@@ -179,8 +162,8 @@ def main():
             sp1_f.set_xlabel("Frequency (Hz)")
             sp1_f.set_ylabel("Power (dBW)")
 
-            x_o = scipy.array(d)
-            t_o = scipy.arange(0, Tmax_o, Ts_o)
+            x_o = numpy.array(d)
+            t_o = numpy.arange(0, Tmax_o, Ts_o)
             sp2_o = fig2.add_subplot(Nrows, Ncols, 1+i)
             p2_o = sp2_o.plot(t_o, x_o.real, "b")
             p2_o = sp2_o.plot(t_o, x_o.imag, "r")
