@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +14,7 @@
 
 #include "pfb_channelizer_ccf_impl.h"
 #include <gnuradio/io_signature.h>
-#include <stdio.h>
+#include <cstdio>
 
 #ifdef _MSC_VER
 #define round(number) number < 0.0 ? ceil(number - 0.5) : floor(number + 0.5)
@@ -39,8 +27,8 @@ pfb_channelizer_ccf::sptr pfb_channelizer_ccf::make(unsigned int nfilts,
                                                     const std::vector<float>& taps,
                                                     float oversample_rate)
 {
-    return gnuradio::get_initial_sptr(
-        new pfb_channelizer_ccf_impl(nfilts, taps, oversample_rate));
+    return gnuradio::make_block_sptr<pfb_channelizer_ccf_impl>(
+        nfilts, taps, oversample_rate);
 }
 
 pfb_channelizer_ccf_impl::pfb_channelizer_ccf_impl(unsigned int nfilts,
@@ -49,7 +37,7 @@ pfb_channelizer_ccf_impl::pfb_channelizer_ccf_impl(unsigned int nfilts,
     : block("pfb_channelizer_ccf",
             io_signature::make(nfilts, nfilts, sizeof(gr_complex)),
             io_signature::make(1, nfilts, sizeof(gr_complex))),
-      polyphase_filterbank(nfilts, taps, false),
+      polyphase_filterbank(nfilts, taps),
       d_updated(false),
       d_oversample_rate(oversample_rate)
 {
@@ -83,7 +71,7 @@ pfb_channelizer_ccf_impl::pfb_channelizer_ccf_impl(unsigned int nfilts,
     // with the first and put it into the fft object properly for
     // the same effect.
     d_rate_ratio = (int)rintf(d_nfilts / d_oversample_rate);
-    d_idxlut = new int[d_nfilts];
+    d_idxlut.resize(d_nfilts);
     for (unsigned int i = 0; i < d_nfilts; i++) {
         d_idxlut[i] = d_nfilts - ((i + d_rate_ratio) % d_nfilts) - 1;
     }
@@ -103,8 +91,6 @@ pfb_channelizer_ccf_impl::pfb_channelizer_ccf_impl(unsigned int nfilts,
     set_tag_propagation_policy(TPP_ONE_TO_ONE);
 }
 
-pfb_channelizer_ccf_impl::~pfb_channelizer_ccf_impl() { delete[] d_idxlut; }
-
 void pfb_channelizer_ccf_impl::set_taps(const std::vector<float>& taps)
 {
     gr::thread::scoped_lock guard(d_mutex);
@@ -129,7 +115,7 @@ void pfb_channelizer_ccf_impl::set_channel_map(const std::vector<int>& map)
         unsigned int max = (unsigned int)*std::max_element(map.begin(), map.end());
         if (max >= d_nfilts) {
             throw std::invalid_argument(
-                "pfb_channelizer_ccf_impl::set_channel_map: map range out of bounds.\n");
+                "pfb_channelizer_ccf_impl::set_channel_map: map range out of bounds.");
         }
         d_channel_map = map;
     }
@@ -174,7 +160,7 @@ int pfb_channelizer_ccf_impl::general_work(int noutput_items,
         last = i;
         while (i >= 0) {
             in = (gr_complex*)input_items[j];
-            d_fft->get_inbuf()[d_idxlut[j]] = d_fir_filters[i]->filter(&in[n]);
+            d_fft->get_inbuf()[d_idxlut[j]] = d_fir_filters[i].filter(&in[n]);
             j++;
             i--;
         }
@@ -182,7 +168,7 @@ int pfb_channelizer_ccf_impl::general_work(int noutput_items,
         i = d_nfilts - 1;
         while (i > last) {
             in = (gr_complex*)input_items[j];
-            d_fft->get_inbuf()[d_idxlut[j]] = d_fir_filters[i]->filter(&in[n - 1]);
+            d_fft->get_inbuf()[d_idxlut[j]] = d_fir_filters[i].filter(&in[n - 1]);
             j++;
             i--;
         }
