@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +24,7 @@ pfb_synthesizer_ccf::sptr pfb_synthesizer_ccf::make(unsigned int numchans,
                                                     const std::vector<float>& taps,
                                                     bool twox)
 {
-    return gnuradio::get_initial_sptr(new pfb_synthesizer_ccf_impl(numchans, taps, twox));
+    return gnuradio::make_block_sptr<pfb_synthesizer_ccf_impl>(numchans, taps, twox);
 }
 
 pfb_synthesizer_ccf_impl::pfb_synthesizer_ccf_impl(unsigned int numchans,
@@ -48,23 +36,23 @@ pfb_synthesizer_ccf_impl::pfb_synthesizer_ccf_impl(unsigned int numchans,
                         numchans),
       d_updated(false),
       d_numchans(numchans),
-      d_state(0)
+      d_state(0),
+      d_twox(twox ? 2 : 1)
 {
     // set up 2x multiplier; if twox==True, set to 2, otherwise to 1
-    d_twox = (twox ? 2 : 1);
     if (d_numchans % d_twox != 0) {
         throw std::invalid_argument("pfb_synthesizer_ccf_impl: number of channels must "
-                                    "be even for 2x oversampling.\n");
+                                    "be even for 2x oversampling.");
     }
 
-    d_filters = std::vector<kernel::fir_filter_with_buffer_ccf*>(d_twox * d_numchans);
+    d_filters.reserve(d_twox * d_numchans);
     d_channel_map.resize(d_twox * d_numchans);
 
     // Create an FIR filter for each channel and zero out the taps
     // and set the default channel map
     std::vector<float> vtaps(0, d_twox * d_numchans);
     for (unsigned int i = 0; i < d_twox * d_numchans; i++) {
-        d_filters[i] = new kernel::fir_filter_with_buffer_ccf(vtaps);
+        d_filters.emplace_back(vtaps);
         d_channel_map[i] = i;
     }
 
@@ -72,20 +60,12 @@ pfb_synthesizer_ccf_impl::pfb_synthesizer_ccf_impl(unsigned int numchans,
     set_taps(taps);
 
     // Create the IFFT to handle the input channel rotations
-    d_fft = new fft::fft_complex(d_twox * d_numchans, false);
+    d_fft = new fft::fft_complex_rev(d_twox * d_numchans);
     std::fill_n(d_fft->get_inbuf(), d_twox * d_numchans, 0);
 
     set_output_multiple(d_numchans);
 }
 
-pfb_synthesizer_ccf_impl::~pfb_synthesizer_ccf_impl()
-{
-    delete d_fft;
-    for (unsigned int i = 0; i < d_twox * d_numchans; i++) {
-        delete d_filters[i];
-    }
-}
-
 void pfb_synthesizer_ccf_impl::set_taps(const std::vector<float>& taps)
 {
     gr::thread::scoped_lock guard(d_mutex);
@@ -99,7 +79,6 @@ void pfb_synthesizer_ccf_impl::set_taps(const std::vector<float>& taps)
 
     // Because we keep our own buffers inside the filters, we don't
     // need history.
-    set_history(1);
     d_updated = true;
 }
 
@@ -137,7 +116,7 @@ void pfb_synthesizer_ccf_impl::set_taps1(const std::vector<float>& taps)
         }
 
         // Set the filter taps for each channel
-        d_filters[i]->set_taps(d_taps[i]);
+        d_filters[i].set_taps(d_taps[i]);
     }
 }
 
@@ -190,8 +169,8 @@ void pfb_synthesizer_ccf_impl::set_taps2(const std::vector<float>& taps)
         }
 
         // Set the filter taps for each channel
-        d_filters[i]->set_taps(d_taps[i]);
-        d_filters[d_numchans + i]->set_taps(d_taps[d_numchans + i]);
+        d_filters[i].set_taps(d_taps[i]);
+        d_filters[d_numchans + i].set_taps(d_taps[d_numchans + i]);
     }
 }
 
@@ -219,7 +198,7 @@ void pfb_synthesizer_ccf_impl::set_channel_map(const std::vector<int>& map)
         int min = *std::min_element(map.begin(), map.end());
         if ((max >= static_cast<int>(d_twox * d_numchans)) || (min < 0)) {
             throw std::invalid_argument(
-                "pfb_synthesizer_ccf_impl::set_channel_map: map range out of bounds.\n");
+                "pfb_synthesizer_ccf_impl::set_channel_map: map range out of bounds.");
         }
         d_channel_map = map;
 
@@ -259,7 +238,7 @@ int pfb_synthesizer_ccf_impl::work(int noutput_items,
             d_fft->execute();
 
             for (i = 0; i < d_numchans; i++) {
-                out[i] = d_filters[i]->filter(d_fft->get_outbuf()[i]);
+                out[i] = d_filters[i].filter(d_fft->get_outbuf()[i]);
             }
             out += d_numchans;
         }
@@ -282,8 +261,8 @@ int pfb_synthesizer_ccf_impl::work(int noutput_items,
             // determine which IFFT buffer position to pull from.
             for (i = 0; i < d_numchans; i++) {
                 out[i] =
-                    d_filters[i]->filter(d_fft->get_outbuf()[d_state * d_numchans + i]);
-                out[i] += d_filters[d_numchans + i]->filter(
+                    d_filters[i].filter(d_fft->get_outbuf()[d_state * d_numchans + i]);
+                out[i] += d_filters[d_numchans + i].filter(
                     d_fft->get_outbuf()[(d_state ^ 1) * d_numchans + i]);
             }
             d_state ^= 1;
