@@ -4,25 +4,14 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef HISTOGRAM_DISPLAY_PLOT_C
 #define HISTOGRAM_DISPLAY_PLOT_C
 
+#include "TimePrecisionClass.h"
 #include <gnuradio/qtgui/HistogramDisplayPlot.h>
 
 #include <gnuradio/math.h>
@@ -32,31 +21,11 @@
 #include <boost/math/special_functions/round.hpp>
 #include <QColor>
 #include <cmath>
-#include <iostream>
 
 #ifdef _MSC_VER
 #define copysign _copysign
 #endif
 
-class TimePrecisionClass
-{
-public:
-    TimePrecisionClass(const int timeprecision) { d_time_precision = timeprecision; }
-
-    virtual ~TimePrecisionClass() {}
-
-    virtual unsigned int getTimePrecision() const { return d_time_precision; }
-
-    virtual void setTimePrecision(const unsigned int newprecision)
-    {
-        d_time_precision = newprecision;
-    }
-
-protected:
-    unsigned int d_time_precision;
-};
-
-
 class HistogramDisplayZoomer : public QwtPlotZoomer, public TimePrecisionClass
 {
 public:
@@ -70,7 +39,7 @@ public:
         setTrackerMode(QwtPicker::AlwaysOn);
     }
 
-    virtual ~HistogramDisplayZoomer() {}
+    ~HistogramDisplayZoomer() override {}
 
     virtual void updateTrackerText() { updateDisplay(); }
 
@@ -78,7 +47,7 @@ public:
 
 protected:
     using QwtPlotZoomer::trackerText;
-    virtual QwtText trackerText(const QPoint& p) const
+    QwtText trackerText(const QPoint& p) const override
     {
         QwtText t;
         QwtDoublePoint dp = QwtPlotZoomer::invTransform(p);
@@ -220,7 +189,7 @@ void HistogramDisplayPlot::plotNewData(const std::vector<double*> dataPoints,
                 for (uint64_t point = 0; point < numDataPoints; point++) {
                     index = boost::math::iround(1e-20 + (dataPoints[n][point] - d_left) /
                                                             d_width);
-                    if ((index >= 0) && (index < d_bins))
+                    if (index < d_bins)
                         d_ydata[n][static_cast<unsigned int>(index)] += 1;
                 }
             }
