@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,8 +17,8 @@
 #include <gnuradio/io_signature.h>
 #include <gnuradio/prefs.h>
 #include <qwt_symbol.h>
-#include <string.h>
 #include <volk/volk.h>
+#include <cstring>
 
 namespace gr {
 namespace qtgui {
@@ -38,8 +26,7 @@ namespace qtgui {
 const_sink_c::sptr
 const_sink_c::make(int size, const std::string& name, int nconnections, QWidget* parent)
 {
-    return gnuradio::get_initial_sptr(
-        new const_sink_c_impl(size, name, nconnections, parent));
+    return gnuradio::make_block_sptr<const_sink_c_impl>(size, name, nconnections, parent);
 }
 
 const_sink_c_impl::const_sink_c_impl(int size,
@@ -69,8 +56,7 @@ const_sink_c_impl::const_sink_c_impl(int size,
 
     // setup PDU handling input port
     message_port_register_in(pmt::mp("in"));
-    set_msg_handler(pmt::mp("in"),
-                    boost::bind(&const_sink_c_impl::handle_pdus, this, _1));
+    set_msg_handler(pmt::mp("in"), [this](pmt::pmt_t msg) { this->handle_pdus(msg); });
 
     for (int i = 0; i < d_nconnections; i++) {
         d_residbufs_real.push_back(
@@ -149,17 +135,6 @@ void const_sink_c_impl::exec_() { d_qApplication->exec(); }
 
 QWidget* const_sink_c_impl::qwidget() { return d_main_gui; }
 
-#ifdef ENABLE_PYTHON
-PyObject* const_sink_c_impl::pyqwidget()
-{
-    PyObject* w = PyLong_FromVoidPtr((void*)d_main_gui);
-    PyObject* retarg = Py_BuildValue("N", w);
-    return retarg;
-}
-#else
-void* const_sink_c_impl::pyqwidget() { return NULL; }
-#endif
-
 void const_sink_c_impl::set_y_axis(double min, double max)
 {
     d_main_gui->setYaxis(min, max);
