@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #include <gnuradio/qtgui/freqdisplayform.h>
@@ -26,7 +14,6 @@
 #include <QMessageBox>
 #include <QSpacerItem>
 #include <cmath>
-#include <iostream>
 
 FreqDisplayForm::FreqDisplayForm(int nplots, QWidget* parent)
     : DisplayForm(nplots, parent)
@@ -35,6 +22,7 @@ FreqDisplayForm::FreqDisplayForm(int nplots, QWidget* parent)
     d_int_validator->setBottom(0);
 
     d_layout = new QGridLayout(this);
+    d_layout->setContentsMargins(0, 0, 0, 0);
     d_display_plot = new FrequencyDisplayPlot(nplots, this);
     d_layout->addWidget(d_display_plot, 0, 0);
 
@@ -64,9 +52,9 @@ FreqDisplayForm::FreqDisplayForm(int nplots, QWidget* parent)
     connect(
         d_avgmenu, SIGNAL(whichTrigger(float)), this, SLOT(setFFTAverage(const float)));
     connect(d_winmenu,
-            SIGNAL(whichTrigger(gr::filter::firdes::win_type)),
+            SIGNAL(whichTrigger(gr::fft::window::win_type)),
             this,
-            SLOT(setFFTWindowType(const gr::filter::firdes::win_type)));
+            SLOT(setFFTWindowType(const gr::fft::window::win_type)));
 
     PopupMenu* maxymenu = new PopupMenu("Y Max", this);
     d_menu->addAction(maxymenu);
@@ -189,14 +177,14 @@ void FreqDisplayForm::setupControlPanel()
     connect(
         d_sizemenu, SIGNAL(whichTrigger(int)), d_controlpanel, SLOT(toggleFFTSize(int)));
     connect(d_winmenu,
-            SIGNAL(whichTrigger(gr::filter::firdes::win_type)),
+            SIGNAL(whichTrigger(gr::fft::window::win_type)),
             d_controlpanel,
-            SLOT(toggleFFTWindow(gr::filter::firdes::win_type)));
+            SLOT(toggleFFTWindow(gr::fft::window::win_type)));
     connect(this, SIGNAL(signalFFTSize(int)), d_controlpanel, SLOT(toggleFFTSize(int)));
     connect(this,
-            SIGNAL(signalFFTWindow(gr::filter::firdes::win_type)),
+            SIGNAL(signalFFTWindow(gr::fft::window::win_type)),
             d_controlpanel,
-            SLOT(toggleFFTWindow(gr::filter::firdes::win_type)));
+            SLOT(toggleFFTWindow(gr::fft::window::win_type)));
     connect(d_maxhold_act,
             SIGNAL(triggered(bool)),
             d_controlpanel,
@@ -271,7 +259,7 @@ int FreqDisplayForm::getFFTSize() const { return d_fftsize; }
 
 float FreqDisplayForm::getFFTAverage() const { return d_fftavg; }
 
-gr::filter::firdes::win_type FreqDisplayForm::getFFTWindowType() const
+gr::fft::window::win_type FreqDisplayForm::getFFTWindowType() const
 {
     return d_fftwintype;
 }
@@ -298,7 +286,7 @@ void FreqDisplayForm::setFFTAverage(const float newavg)
     // emit signalFFTAverage(newavg);
 }
 
-void FreqDisplayForm::setFFTWindowType(const gr::filter::firdes::win_type newwin)
+void FreqDisplayForm::setFFTWindowType(const gr::fft::window::win_type newwin)
 {
     d_fftwintype = newwin;
     d_winmenu->getActionFromWindow(newwin)->setChecked(true);
@@ -559,21 +547,21 @@ void FreqDisplayForm::notifyFFTSize(const QString& s) { setFFTSize(s.toInt()); }
 void FreqDisplayForm::notifyFFTWindow(const QString& s)
 {
     if (s == "None") {
-        d_fftwintype = gr::filter::firdes::WIN_NONE;
+        d_fftwintype = gr::fft::window::WIN_NONE;
     } else if (s == "Hamming") {
-        d_fftwintype = gr::filter::firdes::WIN_HAMMING;
+        d_fftwintype = gr::fft::window::WIN_HAMMING;
     } else if (s == "Hann") {
-        d_fftwintype = gr::filter::firdes::WIN_HANN;
+        d_fftwintype = gr::fft::window::WIN_HANN;
     } else if (s == "Blackman") {
-        d_fftwintype = gr::filter::firdes::WIN_BLACKMAN;
+        d_fftwintype = gr::fft::window::WIN_BLACKMAN;
     } else if (s == "Blackman-harris") {
-        d_fftwintype = gr::filter::firdes::WIN_BLACKMAN_hARRIS;
+        d_fftwintype = gr::fft::window::WIN_BLACKMAN_hARRIS;
     } else if (s == "Rectangular") {
-        d_fftwintype = gr::filter::firdes::WIN_RECTANGULAR;
+        d_fftwintype = gr::fft::window::WIN_RECTANGULAR;
     } else if (s == "Kaiser") {
-        d_fftwintype = gr::filter::firdes::WIN_KAISER;
+        d_fftwintype = gr::fft::window::WIN_KAISER;
     } else if (s == "Flat-top") {
-        d_fftwintype = gr::filter::firdes::WIN_FLATTOP;
+        d_fftwintype = gr::fft::window::WIN_FLATTOP;
     }
 
     d_winmenu->getActionFromWindow(d_fftwintype)->setChecked(true);
