@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,7 +19,7 @@
 
 #include <volk/volk.h>
 
-#include <string.h>
+#include <cstring>
 
 namespace gr {
 namespace qtgui {
@@ -45,8 +33,8 @@ time_raster_sink_f::sptr time_raster_sink_f::make(double samp_rate,
                                                   int nconnections,
                                                   QWidget* parent)
 {
-    return gnuradio::get_initial_sptr(new time_raster_sink_f_impl(
-        samp_rate, rows, cols, mult, offset, name, nconnections, parent));
+    return gnuradio::make_block_sptr<time_raster_sink_f_impl>(
+        samp_rate, rows, cols, mult, offset, name, nconnections, parent);
 }
 
 time_raster_sink_f_impl::time_raster_sink_f_impl(double samp_rate,
@@ -83,8 +71,7 @@ time_raster_sink_f_impl::time_raster_sink_f_impl(double samp_rate,
 
     // setup PDU handling input port
     message_port_register_in(pmt::mp("in"));
-    set_msg_handler(pmt::mp("in"),
-                    boost::bind(&time_raster_sink_f_impl::handle_pdus, this, _1));
+    set_msg_handler(pmt::mp("in"), [this](pmt::pmt_t msg) { this->handle_pdus(msg); });
 
     d_icols = static_cast<int>(ceil(d_cols));
     d_tmpflt = (float*)volk_malloc(d_icols * sizeof(float), volk_get_alignment());
@@ -144,7 +131,7 @@ void time_raster_sink_f_impl::initialize()
     d_main_gui =
         new TimeRasterDisplayForm(numplots, d_samp_rate, d_rows, d_cols, 1, d_parent);
 
-    if (d_name.size() > 0)
+    if (!d_name.empty())
         set_title(d_name);
 
     // initialize update time to 10 times a second
@@ -155,16 +142,25 @@ void time_raster_sink_f_impl::exec_() { d_qApplication->exec(); }
 
 QWidget* time_raster_sink_f_impl::qwidget() { return d_main_gui; }
 
-#ifdef ENABLE_PYTHON
-PyObject* time_raster_sink_f_impl::pyqwidget()
+void time_raster_sink_f_impl::set_x_label(const std::string& label)
 {
-    PyObject* w = PyLong_FromVoidPtr((void*)d_main_gui);
-    PyObject* retarg = Py_BuildValue("N", w);
-    return retarg;
+    d_main_gui->setXLabel(label);
+}
+
+void time_raster_sink_f_impl::set_x_range(double start, double end)
+{
+    d_main_gui->setXAxis(start, end);
+}
+
+void time_raster_sink_f_impl::set_y_label(const std::string& label)
+{
+    d_main_gui->setYLabel(label);
+}
+
+void time_raster_sink_f_impl::set_y_range(double start, double end)
+{
+    d_main_gui->setYAxis(start, end);
 }
-#else
-void* time_raster_sink_f_impl::pyqwidget() { return NULL; }
-#endif
 
 void time_raster_sink_f_impl::set_update_time(double t)
 {
@@ -300,7 +296,7 @@ double time_raster_sink_f_impl::num_cols() { return d_main_gui->numCols(); }
 
 void time_raster_sink_f_impl::set_multiplier(const std::vector<float>& mult)
 {
-    if (mult.size() == 0) {
+    if (mult.empty()) {
         for (int i = 0; i < d_nconnections; i++) {
             d_mult[i] = 1.0f;
         }
@@ -310,13 +306,13 @@ void time_raster_sink_f_impl::set_multiplier(const std::vector<float>& mult)
         }
     } else {
         throw std::runtime_error(
-            "time_raster_sink_f_impl::set_multiplier incorrect dimensions.\n");
+            "time_raster_sink_f_impl::set_multiplier incorrect dimensions.");
     }
 }
 
 void time_raster_sink_f_impl::set_offset(const std::vector<float>& offset)
 {
-    if (offset.size() == 0) {
+    if (offset.empty()) {
         for (int i = 0; i < d_nconnections; i++) {
             d_offset[i] = 0.0f;
         }
@@ -326,7 +322,7 @@ void time_raster_sink_f_impl::set_offset(const std::vector<float>& offset)
         }
     } else {
         throw std::runtime_error(
-            "time_raster_sink_f_impl::set_offset incorrect dimensions.\n");
+            "time_raster_sink_f_impl::set_offset incorrect dimensions.");
     }
 }
 
